"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TranslatableCollection = void 0;
class TranslatableCollection {
  constructor(props, id) {
    this.props = props;
    this.id = id;
  }
  getId() {
    return this.id;
  }
  setId(id) {
    if (!this.id) {
      this.id = id;
    }
  }
  getCollectionId() {
    return this.props.collectionId;
  }
  getItems() {
    return this.props.items || [];
  }
  setItems(items) {
    const newItems = [];
    for (const item of items) {
      const existingItem = this.getItems().find(existingItem => existingItem.itemId === item.itemId);
      if (!existingItem) {
        newItems.push(item);
        continue;
      }
      newItems.push(existingItem.update({
        value: item.value,
        modifiedBy: item.modifiedBy,
        context: item.context ?? existingItem.context
      }));
    }
    this.props.items = newItems;
  }
  getLastModified() {
    return this.getItems().map(item => item.modifiedOn).sort((a, b) => a.getTime() - b.getTime()).pop();
  }
  getBaseValue(itemId) {
    const item = this.getItems().find(item => item.itemId === itemId);
    return item ? item.value : undefined;
  }
  getItemContext(itemId) {
    const item = this.getItems().find(item => item.itemId === itemId);
    return item ? item.context : undefined;
  }
  getItemModifiedOn(itemId) {
    const item = this.getItems().find(item => item.itemId === itemId);
    return item ? item.modifiedOn : undefined;
  }
}
exports.TranslatableCollection = TranslatableCollection;

//# sourceMappingURL=TranslatableCollection.js.map